Interactive pickers
===================

.. automodule:: cruiseplan.interactive
   :members:



cruiseplan.interactive.campaign_selector module
-----------------------------------------------

.. automodule:: cruiseplan.interactive.campaign_selector
   :members:
   :undoc-members:
   :show-inheritance:

cruiseplan.interactive.station_picker module
--------------------------------------------

.. automodule:: cruiseplan.interactive.station_picker
   :members:
   :undoc-members:
   :show-inheritance:
   :no-index:

cruiseplan.interactive.widgets module
-------------------------------------

.. automodule:: cruiseplan.interactive.widgets
   :members:
   :undoc-members:
   :show-inheritance:

